==> openshift-model-5.8.0-sources.jar: io/fabric8/openshift/api/model/BuildTriggerPolicyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BuildTriggerPolicyBuilder extends io.fabric8.openshift.api.model.BuildTriggerPolicyFluentImpl<io.fabric8.openshift.api.model.BuildTriggerPolicyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.BuildTriggerPolicy,io.fabric8.openshift.api.model.BuildTriggerPolicyBuilder>{
  public BuildTriggerPolicyBuilder() {
    this(false);
  }
  public BuildTriggerPolicyBuilder(java.lang.Boolean validationEnabled) {
    this(new BuildTriggerPolicy(), validationEnabled);
  }
  public BuildTriggerPolicyBuilder(io.fabric8.openshift.api.model.BuildTriggerPolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public BuildTriggerPolicyBuilder(io.fabric8.openshift.api.model.BuildTriggerPolicyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BuildTriggerPolicy(), validationEnabled);
  }
  public BuildTriggerPolicyBuilder(io.fabric8.openshift.api.model.BuildTriggerPolicyFluent<?> fluent,io.fabric8.openshift.api.model.BuildTriggerPolicy instance) {
    this(fluent, instance, false);
  }
  public BuildTriggerPolicyBuilder(io.fabric8.openshift.api.model.BuildTriggerPolicyFluent<?> fluent,io.fabric8.openshift.api.model.BuildTriggerPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBitbucket(instance.getBitbucket()); 
    fluent.withGeneric(instance.getGeneric()); 
    fluent.withGithub(instance.getGithub()); 
    fluent.withGitlab(instance.getGitlab()); 
    fluent.withImageChange(instance.getImageChange()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public BuildTriggerPolicyBuilder(io.fabric8.openshift.api.model.BuildTriggerPolicy instance) {
    this(instance,false);
  }
  public BuildTriggerPolicyBuilder(io.fabric8.openshift.api.model.BuildTriggerPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBitbucket(instance.getBitbucket()); 
    this.withGeneric(instance.getGeneric()); 
    this.withGithub(instance.getGithub()); 
    this.withGitlab(instance.getGitlab()); 
    this.withImageChange(instance.getImageChange()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.BuildTriggerPolicyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.BuildTriggerPolicy build() {
    BuildTriggerPolicy buildable = new BuildTriggerPolicy(fluent.getBitbucket(),fluent.getGeneric(),fluent.getGithub(),fluent.getGitlab(),fluent.getImageChange(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildTriggerPolicyBuilder that = (BuildTriggerPolicyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/BuildTriggerPolicyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BuildTriggerPolicyBuilder extends io.fabric8.openshift.api.model.BuildTriggerPolicyFluentImpl<io.fabric8.openshift.api.model.BuildTriggerPolicyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.BuildTriggerPolicy,io.fabric8.openshift.api.model.BuildTriggerPolicyBuilder>{
  public BuildTriggerPolicyBuilder() {
    this(false);
  }
  public BuildTriggerPolicyBuilder(java.lang.Boolean validationEnabled) {
    this(new BuildTriggerPolicy(), validationEnabled);
  }
  public BuildTriggerPolicyBuilder(io.fabric8.openshift.api.model.BuildTriggerPolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public BuildTriggerPolicyBuilder(io.fabric8.openshift.api.model.BuildTriggerPolicyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BuildTriggerPolicy(), validationEnabled);
  }
  public BuildTriggerPolicyBuilder(io.fabric8.openshift.api.model.BuildTriggerPolicyFluent<?> fluent,io.fabric8.openshift.api.model.BuildTriggerPolicy instance) {
    this(fluent, instance, false);
  }
  public BuildTriggerPolicyBuilder(io.fabric8.openshift.api.model.BuildTriggerPolicyFluent<?> fluent,io.fabric8.openshift.api.model.BuildTriggerPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBitbucket(instance.getBitbucket()); 
    fluent.withGeneric(instance.getGeneric()); 
    fluent.withGithub(instance.getGithub()); 
    fluent.withGitlab(instance.getGitlab()); 
    fluent.withImageChange(instance.getImageChange()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BuildTriggerPolicyBuilder(io.fabric8.openshift.api.model.BuildTriggerPolicy instance) {
    this(instance,false);
  }
  public BuildTriggerPolicyBuilder(io.fabric8.openshift.api.model.BuildTriggerPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBitbucket(instance.getBitbucket()); 
    this.withGeneric(instance.getGeneric()); 
    this.withGithub(instance.getGithub()); 
    this.withGitlab(instance.getGitlab()); 
    this.withImageChange(instance.getImageChange()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.BuildTriggerPolicyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.BuildTriggerPolicy build() {
    BuildTriggerPolicy buildable = new BuildTriggerPolicy(fluent.getBitbucket(),fluent.getGeneric(),fluent.getGithub(),fluent.getGitlab(),fluent.getImageChange(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildTriggerPolicyBuilder that = (BuildTriggerPolicyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
